@@ -11,11 +11,11 @@ Locale::CA - two letter codes for province identification in Canada and vice ver
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -202,6 +202,7 @@ BC:BRITISH COLUMBIA
 MB:MANITOBA
 NB:NEW BRUNSWICK
 NL:NEWFOUNDLAND AND LABRADOR
+NL:NEWFOUNDLAND
 NT:NORTHWEST TERRITORIES
 NS:NOVA SCOTIA
 ON:ONTARIO
@@ -217,6 +218,7 @@ BC:COLOMBIE-BRITANNIQUE
 MB:MANITOBA
 NB:NOUVEAU-BRUNSWICK
 NL:TERRE-NEUVE-ET-LABRADOR
+NL:TERRE-NEUVE
 NT:TERRITOIRES DU NORD-OUEST
 NS:NOUVELLE-ÉCOSSE
 ON:ONTARIO
